==> eam-wshub-proxyclient-11.4-7-sources.jar: net/datastream/schemas/mp_fields/PARTNERORGANIZATIONREFERENCEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour PARTNERORGANIZATIONREFERENCEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="PARTNERORGANIZATIONREFERENCEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTNERID"/>
 *         &lt;element name="REFERENCETYPE" type="{http://schemas.datastream.net/MP_fields}ATTRIBUTESETDEFTYPE_Type"/>
 *         &lt;element name="REFERENCENAME" type="{http://schemas.datastream.net/MP_fields}ATTRIBUTESETNAME_Type"/>
 *         &lt;element name="REFERENCEDESC" type="{http://schemas.datastream.net/MP_fields}ATTRIBUTESETDESC_Type" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PARTNERORGANIZATIONREFERENCEID_Type", propOrder = {
    "partnerid",
    "referencetype",
    "referencename",
    "referencedesc"
})
public class PARTNERORGANIZATIONREFERENCEID_Type {

    @XmlElement(name = "PARTNERID", required = true)
    protected String partnerid;
    @XmlElement(name = "REFERENCETYPE", required = true)
    @XmlSchemaType(name = "string")
    protected ATTRIBUTESETDEFTYPE_Type referencetype;
    @XmlElement(name = "REFERENCENAME", required = true)
    protected String referencename;
    @XmlElement(name = "REFERENCEDESC")
    protected String referencedesc;

    /**
     * Obtient la valeur de la propriété partnerid.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPARTNERID() {
        return partnerid;
    }

    /**
     * Définit la valeur de la propriété partnerid.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPARTNERID(String value) {
        this.partnerid = value;
    }

    /**
     * Obtient la valeur de la propriété referencetype.
     * 
     * @return
     *     possible object is
     *     {@link ATTRIBUTESETDEFTYPE_Type }
     *     
     */
    public ATTRIBUTESETDEFTYPE_Type getREFERENCETYPE() {
        return referencetype;
    }

    /**
     * Définit la valeur de la propriété referencetype.
     * 
     * @param value
     *     allowed object is
     *     {@link ATTRIBUTESETDEFTYPE_Type }
     *     
     */
    public void setREFERENCETYPE(ATTRIBUTESETDEFTYPE_Type value) {
        this.referencetype = value;
    }

    /**
     * Obtient la valeur de la propriété referencename.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getREFERENCENAME() {
        return referencename;
    }

    /**
     * Définit la valeur de la propriété referencename.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setREFERENCENAME(String value) {
        this.referencename = value;
    }

    /**
     * Obtient la valeur de la propriété referencedesc.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getREFERENCEDESC() {
        return referencedesc;
    }

    /**
     * Définit la valeur de la propriété referencedesc.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setREFERENCEDESC(String value) {
        this.referencedesc = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/PARTNERORGANIZATIONREFERENCEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for PARTNERORGANIZATIONREFERENCEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="PARTNERORGANIZATIONREFERENCEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTNERID"/>
 *         &lt;element name="REFERENCETYPE" type="{http://schemas.datastream.net/MP_fields}ATTRIBUTESETDEFTYPE_Type"/>
 *         &lt;element name="REFERENCENAME" type="{http://schemas.datastream.net/MP_fields}ATTRIBUTESETNAME_Type"/>
 *         &lt;element name="REFERENCEDESC" type="{http://schemas.datastream.net/MP_fields}ATTRIBUTESETDESC_Type" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PARTNERORGANIZATIONREFERENCEID_Type", propOrder = {
    "partnerid",
    "referencetype",
    "referencename",
    "referencedesc"
})
public class PARTNERORGANIZATIONREFERENCEID_Type {

    @XmlElement(name = "PARTNERID", required = true)
    protected String partnerid;
    @XmlElement(name = "REFERENCETYPE", required = true)
    @XmlSchemaType(name = "string")
    protected ATTRIBUTESETDEFTYPE_Type referencetype;
    @XmlElement(name = "REFERENCENAME", required = true)
    protected String referencename;
    @XmlElement(name = "REFERENCEDESC")
    protected String referencedesc;

    /**
     * Gets the value of the partnerid property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPARTNERID() {
        return partnerid;
    }

    /**
     * Sets the value of the partnerid property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPARTNERID(String value) {
        this.partnerid = value;
    }

    /**
     * Gets the value of the referencetype property.
     * 
     * @return
     *     possible object is
     *     {@link ATTRIBUTESETDEFTYPE_Type }
     *     
     */
    public ATTRIBUTESETDEFTYPE_Type getREFERENCETYPE() {
        return referencetype;
    }

    /**
     * Sets the value of the referencetype property.
     * 
     * @param value
     *     allowed object is
     *     {@link ATTRIBUTESETDEFTYPE_Type }
     *     
     */
    public void setREFERENCETYPE(ATTRIBUTESETDEFTYPE_Type value) {
        this.referencetype = value;
    }

    /**
     * Gets the value of the referencename property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getREFERENCENAME() {
        return referencename;
    }

    /**
     * Sets the value of the referencename property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setREFERENCENAME(String value) {
        this.referencename = value;
    }

    /**
     * Gets the value of the referencedesc property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getREFERENCEDESC() {
        return referencedesc;
    }

    /**
     * Sets the value of the referencedesc property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setREFERENCEDESC(String value) {
        this.referencedesc = value;
    }

}
